@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def get(vmanage):
     """
     Get policy lists
@@ -13,8 +10,8 @@ def get(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/site"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def create(vmanage, policylist):
@@ -30,8 +27,8 @@ def create(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/site"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def createDefaultSiteList(vmanage):
@@ -46,8 +43,8 @@ def createDefaultSiteList(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site/defaultsite"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint)
+    endpoint = f"dataservice/template/policy/list/site/defaultsite"
+    response = vmanage.apiCall("POST", endpoint)
     return response
 
 def preview(vmanage, policylist):
@@ -63,8 +60,8 @@ def preview(vmanage, policylist):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site/preview"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/site/preview"
+    response = vmanage.apiCall("POST", endpoint, policylist)
     return response
 
 def previewById(vmanage, id):
@@ -80,8 +77,8 @@ def previewById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site/preview/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/site/preview/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def getListsById(vmanage, id):
@@ -97,8 +94,8 @@ def getListsById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/list/site/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def edit(vmanage, policylist, id):
@@ -115,8 +112,8 @@ def edit(vmanage, policylist, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, policylist)
+    endpoint = f"dataservice/template/policy/list/site/{id}"
+    response = vmanage.apiCall("PUT", endpoint, policylist)
     return response
 
 def delete(vmanage, id):
@@ -132,6 +129,6 @@ def delete(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/list/site/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/list/site/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
