@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def MapTrafficProfiles(vmanage, apppayload):
     """
     Set SLA class for policy cloud discovered applications
@@ -14,8 +11,8 @@ def MapTrafficProfiles(vmanage, apppayload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/clouddiscoveredapp"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, apppayload)
+    endpoint = f"dataservice/template/policy/clouddiscoveredapp"
+    response = vmanage.apiCall("POST", endpoint, apppayload)
     return response
 
 def getCustomApps(vmanage):
@@ -30,8 +27,8 @@ def getCustomApps(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/customapp"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/customapp"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def create(vmanage, apppayload):
@@ -47,8 +44,8 @@ def create(vmanage, apppayload):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/customapp"
-    response = vmanage.client.apiCall(HttpMethods.POST, endpoint, apppayload)
+    endpoint = f"dataservice/template/policy/customapp"
+    response = vmanage.apiCall("POST", endpoint, apppayload)
     return response
 
 def getById(vmanage, id):
@@ -64,8 +61,8 @@ def getById(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/customapp/{id}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/template/policy/customapp/{id}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 
 def edit(vmanage, apppayload, id):
@@ -82,8 +79,8 @@ def edit(vmanage, apppayload, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/customapp/{id}"
-    response = vmanage.client.apiCall(HttpMethods.PUT, endpoint, apppayload)
+    endpoint = f"dataservice/template/policy/customapp/{id}"
+    response = vmanage.apiCall("PUT", endpoint, apppayload)
     return response
 
 def delete(vmanage, id):
@@ -99,6 +96,6 @@ def delete(vmanage, id):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/template/policy/customapp/{id}"
-    response = vmanage.client.apiCall(HttpMethods.DELETE, endpoint)
+    endpoint = f"dataservice/template/policy/customapp/{id}"
+    response = vmanage.apiCall("DELETE", endpoint)
     return response
