@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getSigDataCenterList(vmanage, type):
     """
     Get list of data centers for zscaler or umbrella
@@ -14,6 +11,6 @@ def getSigDataCenterList(vmanage, type):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/sig/datacenters/{type}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/sig/datacenters/{type}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
