@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getNeighbors(vmanage, vpnId, peerAddr, asNo, deviceId):
     """
     Get BGP neighbors list (Real Time)
@@ -17,8 +14,8 @@ def getNeighbors(vmanage, vpnId, peerAddr, asNo, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/bgp/neighbors?vpnId={vpnId}&peerAddr={peerAddr}&as={asNo}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/bgp/neighbors?vpnId={vpnId}&peerAddr={peerAddr}&as={asNo}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def createBGPRoutesList(vmanage, vpnId, prefix, nexthop, deviceId):
     """
@@ -36,8 +33,8 @@ def createBGPRoutesList(vmanage, vpnId, prefix, nexthop, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/bgp/routes?vpnId={vpnId}&prefix={prefix}&nexthop={nexthop}&deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/bgp/routes?vpnId={vpnId}&prefix={prefix}&nexthop={nexthop}&deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def createBGPSummary(vmanage, deviceId):
     """
@@ -52,6 +49,6 @@ def createBGPSummary(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/bgp/summary?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/bgp/summary?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
