@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getClient(vmanage, deviceId):
     """
     Get DHCP client from device (Real Time)
@@ -14,8 +11,8 @@ def getClient(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dhcp/client?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dhcp/client?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getInterface(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getInterface(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dhcp/interface?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dhcp/interface?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getServer(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getServer(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dhcp/server?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dhcp/server?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getV6Interface(vmanage, deviceId):
     """
@@ -62,6 +59,6 @@ def getV6Interface(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/dhcpv6/interface?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/dhcpv6/interface?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
