@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getInterface(vmanage, deviceId):
     """
     Get EIGRP interface list from device (Real Time)
@@ -14,8 +11,8 @@ def getInterface(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/eigrp/interface?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/eigrp/interface?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getRoute(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getRoute(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/eigrp/route?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/eigrp/route?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getTopology(vmanage, deviceId):
     """
@@ -46,6 +43,6 @@ def getTopology(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/eigrp/topology?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/eigrp/topology?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
