@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getAssocs(vmanage, deviceId):
     """
     Get NTP peer associations list from device (Real Time)
@@ -14,8 +11,8 @@ def getAssocs(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ntp/associations?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/ntp/associations?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getPeers(vmanage, deviceId):
     """
@@ -30,8 +27,8 @@ def getPeers(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ntp/peer?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/ntp/peer?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getStatus(vmanage, deviceId):
     """
@@ -46,8 +43,8 @@ def getStatus(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/ntp/status?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/ntp/status?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getTeList(vmanage, deviceId):
     """
@@ -62,8 +59,8 @@ def getTeList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/virtualApplication/te?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/virtualApplication/te?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getUtdList(vmanage, deviceId):
     """
@@ -78,8 +75,8 @@ def getUtdList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/virtualApplication/utd?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/virtualApplication/utd?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getWaasList(vmanage, deviceId):
     """
@@ -94,6 +91,6 @@ def getWaasList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/virtualApplication/waas?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/virtualApplication/waas?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
