@@ -1,6 +1,3 @@
-from py_viptela.query_builder import Builder
-from py_viptela import HttpMethods
-
 def getList(vmanage, deviceId):
     """
     Get device reboot history
@@ -14,8 +11,8 @@ def getList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/reboothistory?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/reboothistory?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getDetails(vmanage):
     """
@@ -29,8 +26,8 @@ def getDetails(vmanage):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/reboothistory/details"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/reboothistory/details"
+    response = vmanage.apiCall("GET", endpoint)
     return response
 def getSyncedList(vmanage, deviceId):
     """
@@ -45,6 +42,6 @@ def getSyncedList(vmanage, deviceId):
     
     """
     
-    endpoint = f"https://{vmanage.host}:{vmanage.port}/dataservice/device/reboothistory/synced?deviceId={deviceId}"
-    response = vmanage.client.apiCall(HttpMethods.GET, endpoint)
+    endpoint = f"dataservice/device/reboothistory/synced?deviceId={deviceId}"
+    response = vmanage.apiCall("GET", endpoint)
     return response
